@@ -633,7 +633,6 @@ dynamicforms = {
         dynamicforms.showDialog($dlg.showNewAfterHide, refreshType, listId, doneFunc, dataType);
       }
     }
-    dynamicforms.removeRTFFields();
   },
 
   /**
@@ -1283,7 +1282,11 @@ dynamicforms = {
             callback:   'dynamicforms.redirectToLogin',
             parameters: {path_next: link_next.replace(window.location.origin, '')},
           }]);
-        } else {
+        } else if (xhr.status != 0) {
+          //Fail with status 0 can occcur if request is not done yet and user refreshes browser.
+          //https://stackoverflow.com/a/12621912/9625282
+          //General server error dlg should not display in this case
+
           var body = 'General server error.'
           if (xhr.responseText) {
             body = xhr.responseText;
@@ -1607,39 +1610,111 @@ dynamicforms = {
   },
 
   initRTFField: function initRTFField(fieldId) {
-    var interval = null;
-    var editor = null;
-    var timestamp = Math.floor(Date.now() / 1000);
+    var interval     = null;
+    var editor       = null;
+    var timestamp    = Math.floor(Date.now() / 1000);
     var initFunction = function () {
-        interval = window.setInterval(function () {
-            if (typeof window['tinymce'] != "undefined" && $("#" + fieldId).length === 1) {
-                editor = tinymce.init({
-                    selector: "#" + fieldId,
-                    width: "100%",
-                });
-                window.clearInterval(interval)
-            }
-            if (Math.floor(Date.now() / 1000) - timestamp > 1) {
-                window.clearInterval(interval)
-            }
-        }, 100);
+      interval = window.setInterval(function () {
+        if ($('#' + fieldId).length === 1) {
+          var ckeditor_selector = 'ckeditor-' + fieldId
+          ClassicEditor
+            .create(document.querySelector("[id='" + fieldId + "']"), {
+              toolbar: {
+                removeItems: ['imageUpload', 'mediaEmbed'],
+              },
+              heading: {
+                options: [
+                  {model: 'paragraph', title: 'Paragraph', class: 'ck-heading_paragraph'},
+                  {model: 'heading1', view: 'h1', title: 'Heading 1', class: 'ck-heading_heading1'},
+                  {model: 'heading2', view: 'h2', title: 'Heading 2', class: 'ck-heading_heading2'},
+                  {
+                    model:             'div-alert-primary',
+                    view:              {
+                      name:    'div',
+                      classes: ['alert', 'alert-primary'],
+                    },
+                    title:             'Alert - Primary',
+                    class:             'ck-heading_alert-primary',
+                    converterPriority: 'high',
+                  },
+                  {
+                    model:             'div-alert-secondary',
+                    view:              {
+                      name:    'div',
+                      classes: ['alert', 'alert-secondary'],
+                    },
+                    title:             'Alert - Secondary',
+                    class:             'ck-heading_alert-secondary',
+                    converterPriority: 'high',
+                  },
+                  {
+                    model:             'div-alert-success',
+                    view:              {
+                      name:    'div',
+                      classes: ['alert', 'alert-success'],
+                    },
+                    title:             'Alert - Success',
+                    class:             'ck-heading_alert-success',
+                    converterPriority: 'high',
+                  },
+                  {
+                    model:             'div-alert-danger',
+                    view:              {
+                      name:    'div',
+                      classes: ['alert', 'alert-danger'],
+                    },
+                    title:             'Alert - Danger',
+                    class:             'ck-heading_alert-danger',
+                    converterPriority: 'high',
+                  },
+                  {
+                    model:             'div-alert-warning',
+                    view:              {
+                      name:    'div',
+                      classes: ['alert', 'alert-warning'],
+                    },
+                    title:             'Alert - Warning',
+                    class:             'ck-heading_alert-warning',
+                    converterPriority: 'high',
+                  },
+                  {
+                    model:             'div-alert-info',
+                    view:              {
+                      name:    'div',
+                      classes: ['alert', 'alert-info'],
+                    },
+                    title:             'Alert - Info',
+                    class:             'ck-heading_alert-info',
+                    converterPriority: 'high',
+                  },
+                ],
+              },
+            })
+            .then(editor => {
+              ckeditor_selector = editor;
+            })
+            .catch(error => {
+              console.error(error);
+            });
+          window.clearInterval(interval);
+        }
+        if (Math.floor(Date.now() / 1000) - timestamp > 1) {
+          window.clearInterval(interval)
+        }
+      }, 100);
     }
     initFunction();
   },
 
-  removeRTFFields: function removeRTFFields() {
-    // clear all rich text editors
-    if (typeof window['tinymce'] != "undefined") {
-          tinymce.remove()
-    }
-  },
-
   handleRTFFieldsValue: function handleRTFFieldsValue(_data, $_form) {
     for (var key in _data) {
       if (_data.hasOwnProperty(key)) {
         var textareaInput = $_form.find('textarea[name=' + key + ']')
-        if (textareaInput.length === 1 && !!textareaInput.prop('id') && $('#' + textareaInput.prop('id') + '_ifr').length === 1) {
-          _data[key] = tinymce.get(textareaInput.prop('id')).getContent()
+        if (textareaInput.length === 1 && textareaInput.hasClass('.ck-editor__editable')) {
+          var domEditableElement = document.querySelector('.ck-editor__editable');
+          if (domEditableElement !== 'undefined') {
+            _data[key] = domEditableElement.ckeditorInstance.getData();
+          }
         }
       }
     }
